==> dpxu-1.0.0.tar.gz: dpxu/src/Form/ManagerContactForm.php <==
<?php

namespace Drupal\dpxu\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerTrait;
use Drupal\Core\Session\AccountProxyInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Url;
use Drupal\dpxu\ProxyUserTools;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a User Manager Contact form.
 */
class ManagerContactForm extends FormBase {

  use MessengerTrait;
  use StringTranslationTrait;

  /**
   * The current user service.
   *
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected $currentUser;

  /**
   * Proxy User Tools service.
   *
   * @var \Drupal\dpxu\ProxyUserTools
   */
  private $userTools;

  /**
   * Constructs the ManagerContactForm object.
   *
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   *   The current user service.
   * @param \Drupal\dpxu\ProxyUserTools $user_tools
   *   The user tools service.
   */
  public function __construct(AccountProxyInterface $current_user, ProxyUserTools $user_tools) {
    $this->currentUser = $current_user;
    $this->userTools = $user_tools;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('current_user'),
      $container->get('dpxu.user_tools')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'dpxu_contact_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['dpxu_contact_reason'] = [
      '#type' => 'select',
      '#options' => [
        $this->t('My account information is incorrect'),
        $this->t('I have a problem with my account'),
        $this->t('General enquiry'),
      ],
      '#empty_option' => $this->t('- Please select -'),
      '#title' => $this->t('Reason for sending the message'),
      '#required' => TRUE,
    ];
    $form['dpxu_contact_message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Your message'),
      '#description' => $this->t('Please add some text to explain the problem or question you have'),
      '#required' => TRUE,
      '#states' => ['visible' => ['select[name="dpxu_contact_reason"]' => ['!value' => '']]],
    ];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Send message'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $user_uid = $this->currentUser->id();
    $userTools = $this->userTools;
    if ($userTools->userCanSendContactForm($user_uid)) {
      $flag_reason = $message_reason = '';
      $form_values = $form_state->getValues();

      switch ($form_values['dpxu_contact_reason']) {
        case 0:
          $flag_reason = 'dpxu_update';
          $message_reason = $this->t('My account information is incorrect');
          break;

        case 1:
          $flag_reason = 'dpxu_issue';
          $message_reason = $this->t('I have a problem with my account');
          break;

        case 2:
          $flag_reason = 'dpxu_enquiry';
          $message_reason = $this->t('General enquiry');
          break;
      }

      $message_body = '';
      if (!empty($message_reason)) {
        $message_body .= "$message_reason: \r\n";
      }

      if (!empty($form_values['dpxu_contact_message'])) {
        $message_body .= $form_values['dpxu_contact_message'];
        $message = [
          'key' => !empty($flag_reason) ? $flag_reason : 'dpxu_enquiry',
          'subject' => $this->t('Message from Managed User'),
          'body' => $message_body,
        ];

        $userTools->saveContactReasonToTempStore($user_uid, $flag_reason);
        $sentResponse = $userTools->sendUserContactMessage($user_uid, $message);
        if ($sentResponse) {
          $displayText = $this->t('Thank you, your message has been sent to your manager. Please wait for their response.');
        }
        else {
          $displayText = $this->t('Sorry, we have been unable to contact your manager. Please get in touch with an administrator to discuss your issue.');
        }
        $this->messenger()->addMessage($displayText);
      }
    }

    $url = Url::fromRoute('entity.user.canonical', ['user' => $user_uid]);
    $form_state->setRedirectUrl($url);
  }

}

==> dpxu-1.0.3.tar.gz: dpxu/src/Form/ManagerContactForm.php <==
<?php

namespace Drupal\dpxu\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Messenger\MessengerTrait;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Core\Url;
use Drupal\dpxu\ProxyUserTools;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a User Manager Contact form.
 */
class ManagerContactForm extends FormBase {

  use MessengerTrait;
  use StringTranslationTrait;

  /**
   * Proxy User Tools service.
   *
   * @var \Drupal\dpxu\ProxyUserTools
   */
  private $userTools;

  /**
   * Constructs the ManagerContactForm object.
   *
   * @param \Drupal\dpxu\ProxyUserTools $user_tools
   *   The user tools service.
   */
  public function __construct(ProxyUserTools $user_tools) {
    $this->userTools = $user_tools;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('dpxu.user_tools')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'dpxu_contact_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['dpxu_contact_reason'] = [
      '#type' => 'select',
      '#options' => [
        $this->t('My account information is incorrect'),
        $this->t('I have a problem with my account'),
        $this->t('General enquiry'),
      ],
      '#empty_option' => $this->t('- Please select -'),
      '#title' => $this->t('Reason for sending the message'),
      '#required' => TRUE,
    ];
    $form['dpxu_contact_message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Your message'),
      '#description' => $this->t('Please add some text to explain the problem or question you have'),
      '#required' => TRUE,
      '#states' => ['visible' => ['select[name="dpxu_contact_reason"]' => ['!value' => '']]],
    ];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Send message'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $user_uid = $this->currentUser()->id();
    $userTools = $this->userTools;
    if ($userTools->userCanSendContactForm($user_uid)) {
      $flag_reason = $message_reason = '';
      $form_values = $form_state->getValues();

      switch ($form_values['dpxu_contact_reason']) {
        case 0:
          $flag_reason = 'dpxu_update';
          $message_reason = $this->t('My account information is incorrect');
          break;

        case 1:
          $flag_reason = 'dpxu_issue';
          $message_reason = $this->t('I have a problem with my account');
          break;

        case 2:
          $flag_reason = 'dpxu_enquiry';
          $message_reason = $this->t('General enquiry');
          break;
      }

      $message_body = '';
      if (!empty($message_reason)) {
        $message_body .= "$message_reason: \r\n";
      }

      if (!empty($form_values['dpxu_contact_message'])) {
        $message_body .= $form_values['dpxu_contact_message'];
        $message = [
          'key' => !empty($flag_reason) ? $flag_reason : 'dpxu_enquiry',
          'subject' => $this->t('Message from Managed User'),
          'body' => $message_body,
        ];

        $userTools->saveContactReasonToTempStore($user_uid, $flag_reason);
        $sentResponse = $userTools->sendUserContactMessage($user_uid, $message);
        if ($sentResponse) {
          $displayText = $this->t('Thank you, your message has been sent to your manager. Please wait for their response.');
        }
        else {
          $displayText = $this->t('Sorry, we have been unable to contact your manager. Please get in touch with an administrator to discuss your issue.');
        }
        $this->messenger()->addMessage($displayText);
      }
    }

    $url = Url::fromRoute('entity.user.canonical', ['user' => $user_uid]);
    $form_state->setRedirectUrl($url);
  }

}
